@@ -18,13 +18,13 @@
 %                    Based on kmiya's sixel (2014-03-28)                      %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999 ImageMagick Studio LLC, a non-profit organization           %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    https://imagemagick.org/script/license.php                               %
+%    https://imagemagick.org/license/                                         %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -117,7 +117,7 @@ typedef struct sixel_output {
 
     Image *image;
     int pos;
-    unsigned char buffer[SIXEL_OUTPUT_PACKET_SIZE*2];
+    unsigned char buffer[MagickMax(SIXEL_OUTPUT_PACKET_SIZE*2,MagickPathExtent)];
 
 } sixel_output_t;
 
@@ -187,9 +187,9 @@ static int hls_to_rgb(int hue, int lum, int sat)
         }
         Magic1 = (int) (2 * (ssize_t) lum) - Magic2;
 
-        B = (hue_to_rgb(Magic1, Magic2, (ssize_t) hue + (HLSMAX / 3)) * RGBMAX + (HLSMAX / 2)) / HLSMAX;
+        B = (hue_to_rgb(Magic1, Magic2, (ssize_t) hue + (HLSMAX / 3)) * (ssize_t) RGBMAX + (HLSMAX / 2)) / HLSMAX;
         R = (hue_to_rgb(Magic1, Magic2, hue) * RGBMAX + (ssize_t) (HLSMAX / 2)) / HLSMAX;
-        G = (hue_to_rgb(Magic1, Magic2, (ssize_t) hue - (HLSMAX / 3)) * RGBMAX + (HLSMAX/2)) / HLSMAX;
+        G = (hue_to_rgb(Magic1, Magic2, (ssize_t) hue - (HLSMAX / 3)) * (ssize_t) RGBMAX + (HLSMAX/2)) / HLSMAX;
     }
     return SIXEL_RGB(R, G, B);
 }
@@ -1048,7 +1048,7 @@ static Image *ReadSIXELImage(const ImageInfo *image_info,ExceptionInfo *exceptio
         continue;
       if ((*p == '}') && (*(p+1) == ';'))
         break;
-      p+=strlen(p);
+      p+=(ptrdiff_t) strlen(p);
       offset=p-sixel_buffer;
       if ((size_t) (offset+MaxTextExtent+1) < length)
         continue;
@@ -1133,7 +1133,10 @@ static Image *ReadSIXELImage(const ImageInfo *image_info,ExceptionInfo *exceptio
   */
   sixel_pixels=(unsigned char *) RelinquishMagickMemory(sixel_pixels);
   sixel_palette=(unsigned char *) RelinquishMagickMemory(sixel_palette);
-  (void) CloseBlob(image);
+  if (CloseBlob(image) == MagickFalse)
+    status=MagickFalse;
+  if (status == MagickFalse)
+    return(DestroyImageList(image));
   return(GetFirstImageInList(image));
 }
 
@@ -1372,6 +1375,7 @@ static MagickBooleanType WriteSIXELImage(const ImageInfo *image_info,
     sixel_palette, image->colors, -1, output);
   sixel_pixels =(unsigned char *) RelinquishMagickMemory(sixel_pixels);
   output = (sixel_output_t *) RelinquishMagickMemory(output);
-  (void) CloseBlob(image);
+  if (CloseBlob(image) == MagickFalse)
+    status=MagickFalse;
   return(status);
 }
