@@ -17,13 +17,13 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999 ImageMagick Studio LLC, a non-profit organization           %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    https://imagemagick.org/script/license.php                               %
+%    https://imagemagick.org/license/                                         %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -325,7 +325,7 @@ static Image *ReadXPMImage(const ImageInfo *image_info,ExceptionInfo *exception)
       continue;
     if ((*p == '}') && (*(p+1) == ';'))
       break;
-    p+=strlen(p);
+    p+=(ptrdiff_t) strlen(p);
     offset=p-xpm_buffer;
     if ((size_t) (offset+MaxTextExtent) < length)
       continue;
@@ -511,7 +511,7 @@ static Image *ReadXPMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           if (image->storage_class == PseudoClass)
             SetPixelIndex(indexes+x,j);
           *r=image->colormap[j];
-          p+=count;
+          p+=(ptrdiff_t) count;
           r++;
         }
         if (x < (ssize_t) image->columns)
@@ -531,7 +531,10 @@ static Image *ReadXPMImage(const ImageInfo *image_info,ExceptionInfo *exception)
   */
   xpm_colors=DestroySplayTree(xpm_colors);
   xpm_buffer=DestroyString(xpm_buffer);
-  (void) CloseBlob(image);
+  if (CloseBlob(image) == MagickFalse)
+    status=MagickFalse;
+  if (status == MagickFalse)
+    return(DestroyImageList(image));
   return(GetFirstImageInList(image));
 }
 
@@ -946,8 +949,9 @@ static MagickBooleanType WritePICONImage(const ImageInfo *image_info,
   }
   picon=DestroyImage(picon);
   (void) WriteBlobString(image,"};\n");
-  (void) CloseBlob(image);
-  return(MagickTrue);
+  if (CloseBlob(image) == MagickFalse)
+    status=MagickFalse;
+  return(status);
 }
 
 /*
@@ -1057,9 +1061,9 @@ static MagickBooleanType WriteXPMImage(const ImageInfo *image_info,Image *image)
                 opacity=i;
                 continue;
               }
-            alpha=(Quantum) TransparentOpacity-(MagickRealType)
+            alpha=(MagickRealType) TransparentOpacity-(MagickRealType)
               image->colormap[i].opacity;
-            beta=(Quantum) TransparentOpacity-(MagickRealType)
+            beta=(MagickRealType) TransparentOpacity-(MagickRealType)
               image->colormap[opacity].opacity;
             if (alpha < beta)
               opacity=i;
@@ -1075,9 +1079,9 @@ static MagickBooleanType WriteXPMImage(const ImageInfo *image_info,Image *image)
                     opacity=i;
                     continue;
                   }
-                alpha=(Quantum) TransparentOpacity-(MagickRealType)
+                alpha=(MagickRealType) TransparentOpacity-(MagickRealType)
                   image->colormap[i].opacity;
-                beta=(Quantum) TransparentOpacity-(MagickRealType)
+                beta=(MagickRealType) TransparentOpacity-(MagickRealType)
                   image->colormap[opacity].opacity;
                 if (alpha < beta)
                   opacity=i;
