@@ -1,12 +1,12 @@
 /*
-  Copyright 1999-2013 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
-  
-  You may not use this file except in compliance with the License.
+
+  You may not use this file except in compliance with the License.  You may
   obtain a copy of the License at
-  
-    http://www.imagemagick.org/script/license.php
-  
+
+    https://imagemagick.org/license/
+
   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@@ -15,8 +15,8 @@
 
   MagickWand montage command-line method.
 */
-#ifndef _MAGICKWAND_MONTAGE_H
-#define _MAGICKWAND_MONTAGE_H
+#ifndef MAGICKWAND_MONTAGE_H
+#define MAGICKWAND_MONTAGE_H
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
